@@ -38,7 +38,7 @@ class AlphaBacktest:
         self.position_volume=defaultdict(int)
         self._is_config=True
         self.config=config
-    def run(self,position_details:pd.DataFrame,open_price:Dict[str,pd.DataFrame],close_price:Dict[str,pd.DataFrame],vwap_price:Dict[str,pd.DataFrame],index_price:Dict[str,pd.Series])->List[float]:
+    def run(self,position_details:pd.DataFrame,open_price:Dict[str,pd.DataFrame],close_price:Dict[str,pd.DataFrame],vwap_price:Dict[str,pd.DataFrame],index_price:Dict[str,float])->List[float]:
         """
         if just want to use close_price,you can input close_price into vwap_price
         index_price:you should input index close price and index_price ,short volume is same to net_value
@@ -67,21 +67,31 @@ class AlphaBacktest:
                     self.position_volume[stock]+=buy_stock_num
                     self._principal-=buy_stock_num*v_p*(1+self._buy_cost_fee)
             self._net_value=self._principal
-            short_index_return=1-(index_price[date_1]/index_price[date_0]-1)
+            
 #             print(short_index_return)
             for stock in self.position_volume:
                 stock_num=self.position_volume[stock]
                 c_p=close_df[stock]
 
-                self._net_value+=c_p*stock_num*short_index_return
+                self._net_value+=c_p*stock_num
             
             self._net_value_list.append(self._net_value)
             date_0=date
         alpha_series=pd.Series(self._net_value_list[1:],index=list(position_details.keys()))
-        first_value=alpha_series.iloc[0]/self.config["principal"]
-        alpha_series=(alpha_series.pct_change(1)+1).fillna(first_value).cumprod()
-        self.alpha_series=alpha_series
-        return alpha_series
+
+        alpha_series=(alpha_series.pct_change(1)+1).fillna(1).cumprod()
+
+        index_price:pd.Series=pd.Series(index_price)
+        index_price=(index_price.pct_change(1)+1).fillna(1).cumprod()
+        alpha_series=alpha_series-1
+        index_price=index_price-1
+        alpha=alpha_series-index_price
+        self.total_return_df=pd.DataFrame(alpha_series)
+        self.total_return_df.columns=["return"]
+        self.total_return_df["alpha"]=alpha
+        self.total_return_df["index"]=index_price
+
+        return self.total_return_df
     # # 在回测中用到的函数，不需要联网
     def get_risk_index(self,return_se): #输入收益率序列，从0开始
 
@@ -110,18 +120,19 @@ class AlphaBacktest:
 
         return total_returns,total_an_returns,sharpe,max_drawdown
     def summary(self):
+        
         summary = pd.DataFrame(index=['总收益','年化收益','夏普率','最大回撤'])
         #     summary['ret'] = get_risk_index(return_all_df['ret'].cumprod()-1)
-        summary['alpha']=self.get_risk_index(self.alpha_series-1)
+        summary['alpha']=self.get_risk_index(self.total_return_df["alpha"])
         #     summary['index']=get_risk_index(return_all_df['index'].cumprod()-1)
         summary.drop(index = '总收益',inplace=True)
         summary = summary.T
         #     summary['每日收益'] = (return_all_df).mean()
 
         # print('\n全阶段内，每次调仓平均交易换手股票百分比为：{}'.format(round(np.mean(tur_list),3)))
-        print('=====策略运行时间：{} 至 {}====='.format(str(self.alpha_series.index[0])[:10],str(self.alpha_series.index[-1])[:10]))
-        self.alpha_series.plot(figsize=(10,4))
-        plt.legend(["alpha"])
+        print('=====策略运行时间：{} 至 {}====='.format(str(self.total_return_df["alpha"].index[0])[:10],str(self.total_return_df["alpha"].index[-1])[:10]))
+        self.total_return_df.plot(figsize=(10,4))
+        # plt.legend(["alpha"])
 
 
         # 换手率绘图
